"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const uuid_1 = require("uuid");
const LockDao_1 = require("../LockDao");
describe('Test LockDao #findOne', () => {
    it('should return null when query not found', async () => {
        const lockDao = new LockDao_1.LockDao();
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder({}).where('id', (0, uuid_1.v4)());
        jest.spyOn(data_access_layer_1.CrudRepository.prototype, 'findOne').mockResolvedValueOnce(null);
        const queryResponse = await lockDao.findOne(queryBuilder.build());
        expect(queryResponse).toBe(null);
    });
    it('should return lock model object when found', async () => {
        const lockDao = new LockDao_1.LockDao();
        const lockID = (0, uuid_1.v4)();
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder({}).where('id', lockID);
        const response = { id: lockID };
        const spyQuery = jest.spyOn(data_access_layer_1.CrudRepository.prototype, 'findOne').mockResolvedValueOnce(response);
        const queryResponse = await lockDao.findOne(queryBuilder.build());
        expect(queryResponse).toBe(response);
        spyQuery.mockClear();
    });
});
describe('Test LockDao #create', () => {
    it('should return lock model object once created', async () => {
        const lockDao = new LockDao_1.LockDao();
        const LOCK_TIMEOUT = 15 * 60000;
        const lockTimeOutMs = Date.now() + LOCK_TIMEOUT;
        const lockAttributes = {
            id: (0, uuid_1.v4)(),
            name: 'test',
            systemServiceInstanceId: 0,
            timeoutAt: new Date(Date.now() + lockTimeOutMs),
            createdAt: new Date(),
            updatedAt: new Date()
        };
        const response = { id: lockAttributes.id, name: lockAttributes.name, timeoutAt: lockAttributes.timeoutAt };
        const spyQuery = jest.spyOn(data_access_layer_1.CrudRepository.prototype, 'create').mockResolvedValueOnce(response);
        const queryResponse = await lockDao.create(lockAttributes);
        expect(queryResponse).toBe(response);
        spyQuery.mockClear();
    });
});
describe('Test LockDao #delete', () => {
    it('should return count of records deleted', async () => {
        const lockDao = new LockDao_1.LockDao();
        const lockID = (0, uuid_1.v4)();
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder({}).where('id', lockID);
        const spyQuery = jest.spyOn(data_access_layer_1.CrudRepository.prototype, 'delete').mockResolvedValueOnce(1);
        const response = await lockDao.delete(queryBuilder.build());
        expect(response).toBe(1);
        spyQuery.mockClear();
    });
});
//# sourceMappingURL=LockDao.test.js.map